@@ -84,7 +84,7 @@ regroup <- function(x, groups = NULL) {
 #' @export
 regroup_ <- function(x, groups = NULL) {
     if (!inherits(x, "incidence2"))
-        stop("`x` must be an <incidence2> object.")
+        .stop("`x` must be an <incidence2> object.")
 
     groups_expr <- rlang::enquo(groups)
     groups_position <- tidyselect::eval_select(groups_expr, data = x)
@@ -95,7 +95,7 @@ regroup_ <- function(x, groups = NULL) {
         return(x)
 
     if (!all(groups %in% group_variables))
-        stop("Not all variables from `groups` are groupings of `x`.")
+        .stop("Not all variables from `groups` are groupings of `x`.")
 
     # rebuild incidence
     date_variable <- attr(x, "date_index")
