@@ -11,4 +11,12 @@ test_that("summarise works", {
         summarise(dat, sum(count)),
         summarise(as_tibble(dat), sum(count), .by = c(count_variable, hospital))
     )
+
+    expect_error(summarise(dat, .by = "hospital"))
+    expect_snapshot(error = TRUE, summarise(dat, .by = "hospital"))
+
+
+    expect_error(summarise(dat, .groups = "keep"))
+    expect_snapshot(error = TRUE, summarise(dat, .groups = "keep"))
+
 })
